/*
 * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
 *
 * Squid software is distributed under GPLv2+ license and includes
 * contributions from numerous individuals and organizations.
 * Please see the COPYING and CONTRIBUTORS files for details.
 */

/* DEBUG: section 20    Storage Manager Swapin Functions */

#ifndef SQUID_SRC_STORE_SWAPIN_H
#define SQUID_SRC_STORE_SWAPIN_H

class store_client;
void storeSwapInStart(store_client *);

#endif /* SQUID_SRC_STORE_SWAPIN_H */

